Version history
===============

1.1.0
-----

- Added typeguard checks to fail early if arguments of wrong types are passed to functions

1.0.1
-----

- Fixed the Asphalt dependency specification to work with setuptools older than 8.0

1.0.0
-----

Initial release.
